See [parent `readme.md`](../readme.md) for explanation of ids these docs use.

There are several `feature_status`-es:
*   `TBD`: not clear yet whether useful or adequate - to be discussed.
*   `TODO`: clear how it should work, but not implemented.
*   `PARTIAL`: implemented somehow initially for demo but may need more work.
*   `TEST`: implemented and seems working - cover by tests.
*   `DONE`: all good, maintain.
*   `OBSOLETE`: no more applicable.
